@@ -52,9 +52,9 @@ class BlobDataCSV(CSVParser.CSVParser):
         super().__init__(filename, df=df, use_dask=use_dask)
         if not use_dask:
             self.props_keys       = [x for x in self.header[1:]
-                                     if not x.startswith(CSVParser.CONTRAINTS_PREFIX) and x != BLOB_PATH]
+                                     if not x.startswith(CSVParser.CONSTRAINTS_PREFIX) and x != BLOB_PATH]
             self.constraints_keys = [x for x in self.header[1:]
-                                     if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                     if x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
             self.command = "AddBlob"
 
     def getitem(self, idx):
